@@ -6,9 +6,12 @@ use Carp qw/confess/;
 
 use base 'Test2::Compare::Base';
 
-our $VERSION = '0.000054';
+our $VERSION = '0.000063';
 
-use Test2::Util::HashBase qw/input negate/;
+use Test2::Util::HashBase qw/input/;
+
+# Overloads '!' for us.
+use Test2::Compare::Negatable;
 
 sub init {
     my $self = shift;
